==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/item/component/SunHatRendererComponent.java <==
package com.github.thedeathlycow.scorchful.item.component;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.function.Consumer;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9299;

public record SunHatRendererComponent(
        boolean replaceArmorModel,
        boolean showTooltip
) implements class_9299 {
    public static final SunHatRendererComponent DEFAULT = new SunHatRendererComponent(true, true);

    public static final Codec<SunHatRendererComponent> CODEC = RecordCodecBuilder.create(
            instance -> instance.group(
                    Codec.BOOL
                            .lenientOptionalFieldOf("replace_armor_model", DEFAULT.replaceArmorModel)
                            .forGetter(SunHatRendererComponent::replaceArmorModel),
                    Codec.BOOL
                            .lenientOptionalFieldOf("show_tooltip", DEFAULT.showTooltip)
                            .forGetter(SunHatRendererComponent::showTooltip)
            ).apply(instance, SunHatRendererComponent::new)
    );

    public static final class_9139<class_9129, SunHatRendererComponent> PACKET_CODEC = class_9139.method_56435(
            class_9135.field_48547,
            SunHatRendererComponent::replaceArmorModel,
            class_9135.field_48547,
            SunHatRendererComponent::showTooltip,
            SunHatRendererComponent::new
    );

    public static final class_2960 SHADE_OVERLAY_TEXTURE = Scorchful.id("misc/shade_overlay");

    private static final class_2561 TOOLTIP = class_2561.method_43471(
            "item.scorchful.sun_hat.tooltip"
    ).method_10862(
            class_2583.field_24360
                    .method_10977(class_124.field_1078)
                    .method_10978(true)
    );

    @Override
    public void method_57409(class_1792.class_9635 context, Consumer<class_2561> tooltip, class_1836 type) {
        if (this.showTooltip()) {
            tooltip.accept(TOOLTIP);
        }
    }
}

==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/item/component/SunHatRendererComponent.java <==
package com.github.thedeathlycow.scorchful.item.component;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import java.util.function.Consumer;
import net.minecraft.class_124;
import net.minecraft.class_1792;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_2960;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9299;
import net.minecraft.class_9473;

public record SunHatRendererComponent(
        boolean replaceArmorModel,
        boolean showTooltip
) implements class_9299 {
    public static final SunHatRendererComponent DEFAULT = new SunHatRendererComponent(true, true);

    public static final Codec<SunHatRendererComponent> CODEC = RecordCodecBuilder.create(
            instance -> instance.group(
                    Codec.BOOL
                            .lenientOptionalFieldOf("replace_armor_model", DEFAULT.replaceArmorModel)
                            .forGetter(SunHatRendererComponent::replaceArmorModel),
                    Codec.BOOL
                            .lenientOptionalFieldOf("show_tooltip", DEFAULT.showTooltip)
                            .forGetter(SunHatRendererComponent::showTooltip)
            ).apply(instance, SunHatRendererComponent::new)
    );

    public static final class_9139<class_9129, SunHatRendererComponent> PACKET_CODEC = class_9139.method_56435(
            class_9135.field_48547,
            SunHatRendererComponent::replaceArmorModel,
            class_9135.field_48547,
            SunHatRendererComponent::showTooltip,
            SunHatRendererComponent::new
    );

    public static final class_2960 SHADE_OVERLAY_TEXTURE = Scorchful.id("misc/shade_overlay");

    private static final class_2561 TOOLTIP = class_2561.method_43471(
            "item.scorchful.sun_hat.tooltip"
    ).method_10862(
            class_2583.field_24360
                    .method_10977(class_124.field_1078)
                    .method_10978(true)
    );

    @Override
    public void method_57409(class_1792.class_9635 context, Consumer<class_2561> tooltip, class_1836 type, class_9473 components) {
        if (this.showTooltip()) {
            tooltip.accept(TOOLTIP);
        }
    }
}
